@@ -94,8 +94,11 @@ struct options
     int index;                  /* WEP key index        */
     float ffact;                /* bruteforce factor    */
     int korek;                  /* attack strategy      */
+    
+    int is_fritz;               /* use numeric keyspace */
     int is_alnum;               /* alphanum keyspace    */
     int is_bcdonly;             /* binary coded decimal */
+    
     int do_brute;               /* bruteforce last 2 KB */
     int do_testy;               /* experimental attack  */
 
@@ -254,6 +257,7 @@ char usage[] =
 "\n"
 "      -c         : search alpha-numeric characters only\n"
 "      -t         : search binary coded decimal chr only\n"
+"      -h         : search the numeric key for Fritz!BOX\n"
 "      -d <start> : debug - specify beginning of the key\n"
 "      -m <maddr> : MAC address to filter usable packets\n"
 "      -n <nbits> : WEP key length :  64/128/152/256/512\n"
@@ -1004,7 +1008,7 @@ int crack_wep_thread( void *arg )
             memcpy( S,  R, 256 );
             memcpy( Si, R, 256 );
 
-            for( i = j = 0; i < q; ++i )
+            for( i = j = 0; i < q; i++ )
             {
                 jj[i] = j = ( j + S[i] + K[i % (3 + opt.keylen)] ) & 0xFF;
                 SWAP( S[i], S[j] );
@@ -1230,7 +1234,7 @@ void show_wep_stats( int B, int force )
 
     printf( "\33[7;4HKB    depth   byte(vote)\n" );
 
-    for( i = 0; i <= B; ++i )
+    for( i = 0; i <= B; i++ )
     {
         int j, k = ( ws.ws_col - 20 ) / 9;
 
@@ -1241,7 +1245,7 @@ void show_wep_stats( int B, int force )
             printf( "   %2d  %3d/%3d   ",
                     i, wep.depth[i], wep.fudge[i] );
 
-        for( j = wep.depth[i]; j < k + wep.depth[i]; ++j )
+        for( j = wep.depth[i]; j < k + wep.depth[i]; j++ )
         {
             if( j >= 256 ) break;
 
@@ -1292,14 +1296,14 @@ int check_wep_key( int B )
 
     memcpy( K + 3, wep.key, opt.keylen );
 
-    for( n = 0; n < 32; ++n )
+    for( n = 0; n < 32; n++ )
     {
         xv = 5 * ( rand() % wep.nb_ivs );
 
         memcpy( K, &wep.ivbuf[xv], 3 );
         memcpy( S, R, 256 );
 
-        for( i = j = 0; i < 256; ++i )
+        for( i = j = 0; i < 256; i++ )
         {
             j = ( j + S[i] + K[i % (3 + opt.keylen)]) & 0xFF;
             SWAP( S[i], S[j] );
@@ -1322,7 +1326,7 @@ int check_wep_key( int B )
 
     nb_ascii = 0;
 
-    for( i = 0; i < opt.keylen; ++i )
+    for( i = 0; i < opt.keylen; i++ )
         if(   wep.key[i] == 0 ||
             ( wep.key[i] >= 32 && wep.key[i] < 127 ) )
             nb_ascii++;
@@ -1346,7 +1350,7 @@ int check_wep_key( int B )
         printf( "\33[K\33[%dCKEY FOUND! [ ", n );
     }
 
-    for( i = 0; i < opt.keylen - 1; ++i )
+    for( i = 0; i < opt.keylen - 1; i++ )
         printf( "%02X:", wep.key[i] );
     printf( "%02X ] ",   wep.key[i] );
 
@@ -1354,7 +1358,7 @@ int check_wep_key( int B )
     {
         printf( "(ASCII: " );
 
-        for( i = 0; i < opt.keylen; ++i )
+        for( i = 0; i < opt.keylen; i++ )
             printf( "%c", ( ( wep.key[i] >  31 && wep.key[i] < 127 ) ||
                               wep.key[i] > 160 ) ? wep.key[i] : '.' );
 
@@ -1391,7 +1395,7 @@ int calc_poll( int B )
 
     /* send the current keybyte # to each thread */
 
-    for( cid = 0; cid < opt.nbcpu; ++cid )
+    for( cid = 0; cid < opt.nbcpu; cid++ )
     {
         n = sizeof( int );
 
@@ -1405,13 +1409,13 @@ int calc_poll( int B )
 
     /* collect the votes, multiply by the korek coeffs */
 
-    for( i = 0; i < 256; ++i )
+    for( i = 0; i < 256; i++ )
     {
         wep.poll[B][i].idx = i;
         wep.poll[B][i].val = 0;
     }
 
-    for( cid = 0; cid < opt.nbcpu; ++cid )
+    for( cid = 0; cid < opt.nbcpu; cid++ )
     {
         n = sizeof( votes );
 
@@ -1422,8 +1426,8 @@ int calc_poll( int B )
             _exit( FAILURE );
         }
 
-        for( n = 0, vi = (int *) votes; n < N_ATTACKS; ++n )
-            for( i = 0; i < 256; ++i, ++vi )
+        for( n = 0, vi = (int *) votes; n < N_ATTACKS; n++ )
+            for( i = 0; i < 256; i++, vi++ )
                 wep.poll[B][i].val += *vi * K_COEFF[n];
     }
 
@@ -1436,10 +1440,19 @@ int calc_poll( int B )
 
     if( opt.is_alnum )
     {
-        for( i = 1; i < 32; ++i )
+        for( i = 1; i < 32; i++ )
             wep.poll[B][i].val = -1;
 
-        for( i = 127; i < 256; ++i )
+        for( i = 127; i < 256; i++ )
+            wep.poll[B][i].val = -1;
+    }
+
+    if( opt.is_fritz )
+    {
+        for( i = 0; i < 48; i++ )
+            wep.poll[B][i].val = -1;
+
+        for( i = 58; i < 256; i++ )
             wep.poll[B][i].val = -1;
     }
 
@@ -1447,7 +1460,7 @@ int calc_poll( int B )
 
     if( opt.is_bcdonly )
     {
-        for( i = 1; i < 256; ++i )
+        for( i = 1; i < 256; i++ )
             if( i > 0x99 || ( i & 0x0F ) > 0x09 )
                 wep.poll[B][i].val = -1;
     }
@@ -1584,14 +1597,14 @@ get_ivs:
 
     /* fudge threshold = higest vote divided by fudge factor */
 
-    for( wep.fudge[B] = 1; wep.fudge[B] < 256; ++( wep.fudge[B] ) )
+    for( wep.fudge[B] = 1; wep.fudge[B] < 256; ( wep.fudge[B] )++ )
         if( (float) wep.poll[B][wep.fudge[B]].val <
             (float) wep.poll[B][0].val / opt.ffact )
             break;
 
     /* try the most likely n votes, where n is the fudge threshold */
 
-    for( wep.depth[B] = 0; wep.depth[B] < wep.fudge[B]; ++( wep.depth[B] ) )
+    for( wep.depth[B] = 0; wep.depth[B] < wep.fudge[B]; ( wep.depth[B] )++ )
     {
         switch( update_ivbuf() )
         {
@@ -1623,11 +1636,11 @@ get_ivs:
             /* as noted by Simon Marechal, it's more efficient
              * to just bruteforce the last two keybytes. */
 
-            for( i = 0; i < 256; ++i )
+            for( i = 0; i < 256; i++ )
             {
                 wep.key[B + 1] = i;
 
-                for( j = 0; j < 256; ++j )
+                for( j = 0; j < 256; j++ )
                 {
                     wep.key[B + 2] = j;
 
@@ -1673,7 +1686,7 @@ int do_wep_crack2( int B )
         _exit( FAILURE );
     }
 
-    for( i = 0; i <= B; ++i )
+    for( i = 0; i <= B; i++ )
     {
         if( calc_poll( i ) != SUCCESS )
             return( FAILURE );
@@ -1687,12 +1700,12 @@ int do_wep_crack2( int B )
             show_wep_stats( i, 0 );
     }
 
-    for( wep.fudge[B] = 1; wep.fudge[B] < 256; ++( wep.fudge[B] ) )
+    for( wep.fudge[B] = 1; wep.fudge[B] < 256; ( wep.fudge[B] )++ )
         if( (float) wep.poll[B][wep.fudge[B]].val <
             (float) wep.poll[B][0].val / opt.ffact )
             break;
 
-    for( wep.depth[B] = 0; wep.depth[B] < wep.fudge[B]; ++( wep.depth[B] ) )
+    for( wep.depth[B] = 0; wep.depth[B] < wep.fudge[B]; ( wep.depth[B] )++ )
     {
         switch( update_ivbuf() )
         {
@@ -1706,7 +1719,7 @@ int do_wep_crack2( int B )
         if( ! opt.is_quiet )
             show_wep_stats( B, 0 );
 
-        for( i = B + 1; i < opt.keylen - 2; ++i )
+        for( i = B + 1; i < opt.keylen - 2; i++ )
         {
             if( calc_poll( i ) != SUCCESS )
                 return( FAILURE );
@@ -1720,11 +1733,11 @@ int do_wep_crack2( int B )
                 show_wep_stats( i, 0 );
         }
 
-        for( i = 0; i < 256; ++i )
+        for( i = 0; i < 256; i++ )
         {
             wep.key[opt.keylen - 2] = i;
 
-            for( j = 0; j < 256; ++j )
+            for( j = 0; j < 256; j++ )
             {
                 wep.key[opt.keylen - 1] = j;
 
@@ -1754,13 +1767,13 @@ void calc_pmk( char *key, char *essid, uchar pmk[40] )
     memset( buffer, 0, sizeof( buffer ) );
     strncpy( (char *) buffer, key, sizeof( buffer ) - 1 );
 
-    for( i = 0; i < 64; ++i )
+    for( i = 0; i < 64; i++ )
         buffer[i] ^= 0x36;
 
     sha1_starts( &ctx_ipad );
     sha1_update( &ctx_ipad, buffer, 64 );
 
-    for( i = 0; i < 64; ++i )
+    for( i = 0; i < 64; i++ )
         buffer[i] ^= 0x6A;
 
     sha1_starts( &ctx_opad );
@@ -1773,7 +1786,7 @@ void calc_pmk( char *key, char *essid, uchar pmk[40] )
                (uchar *) essid, slen, pmk );
     memcpy( buffer, pmk, 20 );
 
-    for( i = 1; i < 4096; ++i )
+    for( i = 1; i < 4096; i++ )
     {
         memcpy( &sha1_ctx, &ctx_ipad, sizeof( sha1_ctx ) );
         sha1_update( &sha1_ctx, buffer, 20 );
@@ -1783,7 +1796,7 @@ void calc_pmk( char *key, char *essid, uchar pmk[40] )
         sha1_update( &sha1_ctx, buffer, 20 );
         sha1_finish( &sha1_ctx, buffer );
 
-        for( j = 0; j < 20; ++j )
+        for( j = 0; j < 20; j++ )
             pmk[j] ^= buffer[j];
     }
 
@@ -1792,7 +1805,7 @@ void calc_pmk( char *key, char *essid, uchar pmk[40] )
                (uchar *) essid, slen, pmk + 20 );
     memcpy( buffer, pmk + 20, 20 );
 
-    for( i = 1; i < 4096; ++i )
+    for( i = 1; i < 4096; i++ )
     {
         memcpy( &sha1_ctx, &ctx_ipad, sizeof( sha1_ctx ) );
         sha1_update( &sha1_ctx, buffer, 20 );
@@ -1802,7 +1815,7 @@ void calc_pmk( char *key, char *essid, uchar pmk[40] )
         sha1_update( &sha1_ctx, buffer, 20 );
         sha1_finish( &sha1_ctx, buffer );
 
-        for( j = 0; j < 20; ++j )
+        for( j = 0; j < 20; j++ )
             pmk[j + 20] ^= buffer[j];
     }
 }
@@ -1875,7 +1888,7 @@ int crack_wpa_thread( void *arg )
         v = (uint *) ( k_ipad + 64 );
         w = (uint *) buffer;
 
-        for( i = 0; i < 16; ++i )
+        for( i = 0; i < 16; i++ )
         {
             /* interleave the data */
 
@@ -1890,7 +1903,7 @@ int crack_wpa_thread( void *arg )
         v = (uint *) ( k_opad + 64 );
         w = (uint *) buffer;
 
-        for( i = 0; i < 16; ++i )
+        for( i = 0; i < 16; i++ )
         {
             *w++ = *u++ ^ 0x5C5C5C5C;
             *w++ = *v++ ^ 0x5C5C5C5C;
@@ -1925,7 +1938,7 @@ int crack_wpa_thread( void *arg )
         *w++ = *u++; *w++ = *v++;
         *w++ = *u++; *w++ = *v++;
 
-        for( i = 1; i < 4096; ++i )
+        for( i = 1; i < 4096; i++ )
         {
             memcpy( sha1_ctx, ctx_ipad, 40 );
             shammx_data( sha1_ctx, buffer, wrkbuf );
@@ -1966,7 +1979,7 @@ int crack_wpa_thread( void *arg )
         *w++ = *u++; *w++ = *v++;
         *w++ = *u++; *w++ = *v++;
 
-        for( i = 1; i < 4096; ++i )
+        for( i = 1; i < 4096; i++ )
         {
             memcpy( sha1_ctx, ctx_ipad, 40 );
             shammx_data( sha1_ctx, buffer, wrkbuf );
@@ -2055,7 +2068,7 @@ void show_wpa_stats( char *key, uchar pmk[32], uchar ptk[64],
     printf( "\33[11;7HMaster Key     : " );
 
     if( opt.l33t ) printf( "\33[32;1m" );
-    for( i = 0; i < 32; ++i )
+    for( i = 0; i < 32; i++ )
     {
         if( i == 16 ) printf( "\n\33[23C" );
         printf( "%02X ", pmk[i] );
@@ -2065,7 +2078,7 @@ void show_wpa_stats( char *key, uchar pmk[32], uchar ptk[64],
     printf( "\33[14;7HTranscient Key : " );
 
     if( opt.l33t ) printf( "\33[32;1m" );
-    for( i = 0; i < 64; ++i )
+    for( i = 0; i < 64; i++ )
     {
         if( i > 0 && i % 16 == 0 ) printf( "\n\33[23C" );
         printf( "%02X ", ptk[i] );
@@ -2075,7 +2088,7 @@ void show_wpa_stats( char *key, uchar pmk[32], uchar ptk[64],
     printf( "\33[19;7HEAPOL HMAC     : " );
 
     if( opt.l33t ) printf( "\33[32;1m" );
-    for( i = 0; i < 16; ++i )
+    for( i = 0; i < 16; i++ )
         printf( "%02X ", mic[i] );
 
     printf( "\n" );
@@ -2093,7 +2106,7 @@ int do_wpa_crack( struct AP_info *ap )
 
     /* send the ESSID to each thread */
 
-    for( cid = 0; cid < opt.nbcpu; ++cid )
+    for( cid = 0; cid < opt.nbcpu; cid++ )
     {
         if( safe_write( mc_pipe[cid][1], (void *) ap->essid, 32 ) != 32 )
         {
@@ -2147,7 +2160,7 @@ int do_wpa_crack( struct AP_info *ap )
 
     while( 1 )
     {
-        for( cid = 0; cid < opt.nbcpu; ++cid )
+        for( cid = 0; cid < opt.nbcpu; cid++ )
         {
             /* read a couple of keys (skip those < 8 chars) */
 
@@ -2194,7 +2207,7 @@ int do_wpa_crack( struct AP_info *ap )
             }
         }
 
-        for( cid = 0; cid < opt.nbcpu; ++cid )
+        for( cid = 0; cid < opt.nbcpu; cid++ )
         {
             /* collect and test the master keys */
 
@@ -2209,7 +2222,7 @@ int do_wpa_crack( struct AP_info *ap )
 
             /* compute the pairwise transient key and the frame MIC */
 
-            for( i = 0; i < 4; ++i )
+            for( i = 0; i < 4; i++ )
             {
                 pke[99] = i;
                 hmac_sha1( pmk1, 32, pke, 100, ptk1 + i * 20 );
@@ -2318,7 +2331,7 @@ int main( int argc, char *argv[] )
     {
     usage:
     	printf (usage, progname, 
-    		( max_cpu == 1 ) ? "\n" : "\n      -p <nbcpu> : # of CPU to use\n" );
+    		( max_cpu == 1 ) ? "\n" : "\n      -p <nbcpu> : # of CPU to use (by default, all CPUs)\n" );
         return( ret );
     }
 
@@ -2329,9 +2342,9 @@ int main( int argc, char *argv[] )
     {
 
         if ( max_cpu == 1 )
-        	option = getopt( argc, argv, "a:e:b:qctd:m:n:i:f:k:xyw:0" );
+        	option = getopt( argc, argv, "a:e:b:qcthd:m:n:i:f:k:xyw:0" );
         else
-        	option = getopt( argc, argv, "a:e:b:p:qctd:m:n:i:f:k:xyw:0" );
+        	option = getopt( argc, argv, "a:e:b:p:qcthd:m:n:i:f:k:xyw:0" );
 
         if( option < 0 ) break;
 
@@ -2344,7 +2357,7 @@ int main( int argc, char *argv[] )
 				if ( strcasecmp( optarg, "wep" ) == 0 )
 					opt.amode = 1;
 				
-				if ( strcasecmp( optarg, "wpa" ) == 0 )
+				else if ( strcasecmp( optarg, "wpa" ) == 0 )
 					opt.amode = 2;
 
                 if( opt.amode != 1 && opt.amode != 2 )
@@ -2401,7 +2414,7 @@ int main( int argc, char *argv[] )
                 	printf( "Invalid number of processes.\n" );
                 	return( FAILURE );
                 }
-
+				
 				break;
 				
             case 'q' :
@@ -2413,6 +2426,11 @@ int main( int argc, char *argv[] )
             case 'c' :
 
                 opt.is_alnum = 1;
+                break;
+
+			case 'h' :
+
+                opt.is_fritz = 1;
                 break;
 
             case 't' :
@@ -2712,7 +2730,7 @@ int main( int argc, char *argv[] )
                          break;
             }
 
-            ++i; ap_cur = ap_cur->next;
+            i++; ap_cur = ap_cur->next;
         }
 
         printf( "\n" );
@@ -2730,7 +2748,7 @@ int main( int argc, char *argv[] )
 
                 i = 1; ap_cur = ap_1st;
                 while( ap_cur != NULL && i < n )
-                    { ++i; ap_cur = ap_cur->next; }
+                    { i++; ap_cur = ap_cur->next; }
             }
             while( n < 0 || ap_cur == NULL );
         }
@@ -2797,7 +2815,7 @@ int main( int argc, char *argv[] )
 
     /* create the cracker<->master communication pipes */
 
-    for( i = 0; i < opt.nbcpu; ++i )
+    for( i = 0; i < opt.nbcpu; i++ )
     {
         pipe( mc_pipe[i] );
         pipe( cm_pipe[i] );
@@ -2842,7 +2860,7 @@ int main( int argc, char *argv[] )
 
         memset( &wep, 0, sizeof( wep ) );
 
-        for( i = 0; i < opt.nbcpu; ++i )
+        for( i = 0; i < opt.nbcpu; i++ )
         {
             /* start one thread per cpu */
 
@@ -2878,7 +2896,7 @@ int main( int argc, char *argv[] )
         }
         else
         {
-            for( i = opt.keylen - 3; i < opt.keylen - 2; ++i )
+            for( i = opt.keylen - 3; i < opt.keylen - 2; i++ )
             {
                 do   { ret = do_wep_crack2( i ); }
                 while( ret == RESTART );
@@ -2939,7 +2957,7 @@ int main( int argc, char *argv[] )
             strncpy( ap_cur->essid, opt.essid, sizeof( ap_cur->essid ) - 1 );
         }
 
-        for( i = 0; i < opt.nbcpu; ++i )
+        for( i = 0; i < opt.nbcpu; i++ )
         {
             /* start one thread per cpu */
 
