@@ -2,7 +2,7 @@
  *  802.11 to Ethernet pcap translator
  *
  *  Copyright (C) 2006 Thomas d'Otreppe
- *  Original work: Christophe Devine
+ *  Copyright (C) 2004,2005  Christophe Devine
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@
 #define CRYPT_WEP  1
 #define CRYPT_WPA  2
 
+extern char * getVersion(char * progname, int maj, int min, int submin, int betavers);
+
 const short Sbox[2][256]=
 {
     {
@@ -111,8 +113,9 @@ char usage[] =
 "\n"
 "  %s - (C) 2006 Thomas d\'Otreppe\n"
 "  Original work: Christophe Devine\n"
+"  http://www.aircrack-ng.org\n"
 "\n"
-"  usage: airdecap [options] <pcap file>\n"
+"  usage: airdecap-ng [options] <pcap file>\n"
 "\n"
 "      -l       : don't remove the 802.11 header\n"
 "      -b bssid : access point MAC address filter\n"
@@ -120,14 +123,6 @@ char usage[] =
 "      -e essid : target network ascii identifier\n"
 "      -p pass  : target network WPA passphrase\n"
 "      -w key   : target network WEP key in hex\n"
-"\n"
-"  examples:\n"
-"\n"
-"  airdecap-ng -b 00:09:5B:10:BC:5A open-network.cap\n"
-"  airdecap-ng -w 11A3E229084349BC25D97E2939 wep.cap\n"
-"  airdecap-ng -e my_essid -p my_passphrase tkip.cap\n"
-"\n"
-"  http://www.aircrack-ng.org\n"
 "\n";
 
 
@@ -568,20 +563,6 @@ int write_packet( FILE *f_out, struct pcap_pkthdr *pkh, uchar *h80211 )
     return( 0 );
 }
 
-char * getVersion(char * progname, int maj, int min, int submin)
-{
-	char * temp;
-	temp = (char *) calloc(1,strlen(progname)+50);
-
-	if (submin>0) {
-		sprintf(temp, "%s %d.%d.%d", progname, maj, min, submin);	
-	} else {
-		sprintf(temp, "%s %d.%d", progname, maj, min);
-	}
-	temp = realloc(temp, strlen(temp)+1);
-	return temp;
-}
-
 int main( int argc, char *argv[] )
 {
     time_t tt;
@@ -775,7 +756,7 @@ int main( int argc, char *argv[] )
     if( argc - optind != 1 )
     {
     usage:
-        printf( usage, getVersion("Airdecap-ng", _MAJ, _MIN, _SUB_MIN)  );
+        printf( usage, getVersion("Airdecap-ng", _MAJ, _MIN, _SUB_MIN, _BETA)  );
         return( 1 );
     }
 
