@@ -1780,11 +1780,15 @@ int do_attack_chopchop( void )
             fflush( stdout );
         }
 
-        if( data_end == 40 && ticks[3] > 8 * ( ticks[0] - ticks[3] ) /
+        if( data_end < 41 && ticks[3] > 8 * ( ticks[0] - ticks[3] ) /
                                 (int) ( caplen - ( data_end - 1 ) ) )
         {
+            header_rec:
+
             printf( "\n\nThe AP appears to drop packets shorter "
-                    "than 40 bytes.\n" );
+                    "than %d bytes.\n",data_end );
+
+			data_end = 40;
 
             z = ( ( h80211[1] & 3 ) != 3 ) ? 24 : 30;
 
@@ -1938,6 +1942,8 @@ int do_attack_chopchop( void )
 
             if( ! ( h80211[5] & 1 ) )
             {
+            	if( data_end < 41 ) goto header_rec;
+            	
                 printf( "\n\nFailure: the access point does not properly "
                         "discard frames with an\ninvalid ICV - try running "
                         "aireplay-ng in authenticated mode (-h) instead.\n\n" );
@@ -1974,6 +1980,8 @@ int do_attack_chopchop( void )
 
             if( ! ( h80211[5] & 1 ) )
             {
+            	if( data_end < 41 ) goto header_rec;
+            	
                 printf( "\n\nFailure: the access point does not properly "
                         "discard frames with an\ninvalid ICV - try running "
                         "aireplay-ng in non-authenticated mode instead.\n\n" );
