@@ -186,13 +186,12 @@ char usage[] =
 "      --write    <prefix> : Dump file prefix (mandatory)\n"
 "      -w                  : same as --write \n"
 "\n"
-"  By default, airodump-ng hop on all available channels.\n"
-"  You can make it hop on bg channels only or a channels only:\n"
+"  By default, airodump-ng hop on 2.4Ghz channels.\n"
+"  You can make it capture on other/specific channel(s) by using:\n"
 "      --channel <channel> : Capture on a specific channel\n"
 "      -c                  : Same as --channel\n"
-"      --bg                : Will hop on 2.4Ghz channels\n"
-"      -b                  : same as --bg\n"
 "      -a                  : Will hop on 5Ghz channels\n"
+"      --abg               : Will hop on 2.4Ghz channels\n"
 "\n";
 
 
@@ -1690,37 +1689,56 @@ int set_monitor( char *interface, int fd_raw )
     int pid, status;
     struct iwreq wrq;
 
-    if( G.is_wlanng )
-    {
-        if( ( pid = fork() ) == 0 )
-        {
-            close( 0 ); close( 1 ); close( 2 ); chdir( "/" );
-            execlp( "wlanctl-ng", "wlanctl-ng", interface,
-                    "lnxreq_wlansniff", "enable=true",
-                    "prismheader=true", "wlanheader=false",
-                    "stripfcs=true", "keepwepflags=true", NULL );
-            exit( 1 );
-        }
+	if( strcmp(interface,"prism0") == 0 )
+	{
+		if( ( pid = fork() ) == 0 )
+		{
+			close( 0 ); close( 1 ); close( 2 ); chdir( "/" );
+			execlp( "wl", "wl", "monitor", "1", NULL);
+			exit( 1 );
+		}
+		waitpid( pid, &status, 0 );
+		if( WIFEXITED(status) )
+			return( WEXITSTATUS(status) );
+		return( 1 );		
+	}
+	else
+	{
+		if( G.is_wlanng )
+		{
+			if( ( pid = fork() ) == 0 )
+			{
+				close( 0 ); close( 1 ); close( 2 ); chdir( "/" );
+				execlp( "wlanctl-ng", "wlanctl-ng", interface,
+						"lnxreq_wlansniff", "enable=true",
+						"prismheader=true", "wlanheader=false",
+						"stripfcs=true", "keepwepflags=true", NULL );
+				exit( 1 );
+			}
 
-        waitpid( pid, &status, 0 );
+			waitpid( pid, &status, 0 );
 
-        if( WIFEXITED(status) )
-            return( WEXITSTATUS(status) );
-        return( 1 );
-    }
+			if( WIFEXITED(status) )
+				return( WEXITSTATUS(status) );
+			return( 1 );
+		}
 
-    memset( &wrq, 0, sizeof( struct iwreq ) );
-    strncpy( wrq.ifr_name, interface, IFNAMSIZ );
-    wrq.u.mode = IW_MODE_MONITOR;
-
-    if( ioctl( fd_raw, SIOCSIWMODE, &wrq ) < 0 )
-    {
-        perror( "ioctl(SIOCSIWMODE) failed" );
-        return( 1 );
-    }
-
-    set_channel( interface, fd_raw, 10 );
+		memset( &wrq, 0, sizeof( struct iwreq ) );
+		strncpy( wrq.ifr_name, interface, IFNAMSIZ );
+		wrq.u.mode = IW_MODE_MONITOR;
 
+		if( ioctl( fd_raw, SIOCSIWMODE, &wrq ) < 0 )
+		{
+			perror( "ioctl(SIOCSIWMODE) failed" );
+			return( 1 );
+		}
+	
+	}
+	
+	/* Check later if it's really usefull to set channel here */
+	
+	set_channel( interface, fd_raw, (G.channel == 0 ) ? 10 : G.channel);
+	
     return( 0 );
 }
 
@@ -1854,11 +1872,6 @@ int main( int argc, char *argv[] )
                 G.channels = a_chans;
                 break;
 
-            case 'g' :              
-            case 'b' :
-
-                G.channels = bg_chans;                      
-                break;
 
             case 'c' :
 
@@ -1880,12 +1893,20 @@ int main( int argc, char *argv[] )
                         goto usage;
                 }
                 /*
-                 * else, hop between channels
+                 * else, hop on 2.4Ghz channels
                  * so, no need to break
 				 */
+
+            case 'g' :              
+            case 'b' :
+
+				/* Default behaviour: hop on 2.4Ghz channels */
+                G.channels = bg_chans;                      
+                break;
+
             case 'h' :
                 
-                /* Default behaviour, hop on all available channels */
+                /* hop on all available channels */
                 G.channels     =  abg_chans;
                 break;
 
