@@ -280,7 +280,7 @@ void hmac_md5( uint8 *key, int keylen, uint8 *buffer, int length,
     memcpy( k_ipad, key, keylen );
     memcpy( k_opad, key, keylen );
 
-    for( i = 0; i < 64; ++i )
+    for( i = 0; i < 64; i++ )
     {
         k_ipad[i] ^= 0x36;
         k_opad[i] ^= 0x5C;
@@ -559,7 +559,7 @@ void hmac_sha1( uint8 *key, int keylen, uint8 *buffer, int length,
     memcpy( k_ipad, key, keylen );
     memcpy( k_opad, key, keylen );
 
-    for( i = 0; i < 64; ++i )
+    for( i = 0; i < 64; i++ )
     {
         k_ipad[i] ^= 0x36;
         k_opad[i] ^= 0x5C;
@@ -608,7 +608,7 @@ void rc4_setup( struct rc4_state *s, unsigned char *key,  int length )
 
     j = k = i = 0;
 
-    for(; i < 256; ++i )
+    for(; i < 256; i++ )
     {
         a = n[i];
         j = (unsigned char) ( j + a + key[k] );
@@ -625,7 +625,7 @@ void rc4_crypt( struct rc4_state *s, unsigned char *data, int length )
     y = s->y;
     m = s->m;
 
-    for( i = 0; i < length; ++i )
+    for( i = 0; i < length; i++ )
     {
         x = (unsigned char) ( x + 1 ); a = m[x];
         y = (unsigned char) ( y + a );
@@ -681,7 +681,7 @@ void aes_gen_tables( void )
 
     /* compute pow and log tables over GF(2^8) */
 
-    for( i = 0, x = 1; i < 256; ++i, x ^= XTIME( x ) )
+    for( i = 0, x = 1; i < 256; i++, x ^= XTIME( x ) )
     {
         pow[i] = x;
         log[x] = i;
@@ -689,7 +689,7 @@ void aes_gen_tables( void )
 
     /* calculate the round constants */
 
-    for( i = 0, x = 1; i < 10; ++i, x = XTIME( x ) )
+    for( i = 0, x = 1; i < 10; i++, x = XTIME( x ) )
     {
         RCON[i] = (uint32) x << 24;
     }
@@ -699,7 +699,7 @@ void aes_gen_tables( void )
     FSb[0x00] = 0x63;
     RSb[0x63] = 0x00;
 
-    for( i = 1; i < 256; ++i )
+    for( i = 1; i < 256; i++ )
     {
         x = pow[255 - log[i]];
 
@@ -715,7 +715,7 @@ void aes_gen_tables( void )
 
     /* generate the forward and reverse tables */
 
-    for( i = 0; i < 256; ++i )
+    for( i = 0; i < 256; i++ )
     {
         x = (unsigned char) FSb[i]; y = XTIME( x );
 
@@ -778,7 +778,7 @@ int aes_set_key( aes_context *ctx, uint8 *key, int nbits )
 
     RK = ctx->erk;
 
-    for( i = 0; i < (nbits >> 5); ++i )
+    for( i = 0; i < (nbits >> 5); i++ )
     {
         GET_UINT32_BE( RK[i], key, i * 4 );
     }
@@ -789,7 +789,7 @@ int aes_set_key( aes_context *ctx, uint8 *key, int nbits )
     {
     case 128:
 
-        for( i = 0; i < 10; ++i, RK += 4 )
+        for( i = 0; i < 10; i++, RK += 4 )
         {
             RK[4]  = RK[0] ^ RCON[i] ^
                         ( FSb[ (uint8) ( RK[3] >> 16 ) ] << 24 ) ^
@@ -805,7 +805,7 @@ int aes_set_key( aes_context *ctx, uint8 *key, int nbits )
 
     case 192:
 
-        for( i = 0; i < 8; ++i, RK += 6 )
+        for( i = 0; i < 8; i++, RK += 6 )
         {
             RK[6]  = RK[0] ^ RCON[i] ^
                         ( FSb[ (uint8) ( RK[5] >> 16 ) ] << 24 ) ^
@@ -823,7 +823,7 @@ int aes_set_key( aes_context *ctx, uint8 *key, int nbits )
 
     case 256:
 
-        for( i = 0; i < 7; ++i, RK += 8 )
+        for( i = 0; i < 7; i++, RK += 8 )
         {
             RK[8]  = RK[0] ^ RCON[i] ^
                         ( FSb[ (uint8) ( RK[7] >> 16 ) ] << 24 ) ^
@@ -852,7 +852,7 @@ int aes_set_key( aes_context *ctx, uint8 *key, int nbits )
 
     if( KT_init )
     {
-        for( i = 0; i < 256; ++i )
+        for( i = 0; i < 256; i++ )
         {
             KT0[i] = RT0[ FSb[i] ];
             KT1[i] = RT1[ FSb[i] ];
@@ -870,7 +870,7 @@ int aes_set_key( aes_context *ctx, uint8 *key, int nbits )
     *SK++ = *RK++;
     *SK++ = *RK++;
 
-    for( i = 1; i < ctx->nr; ++i )
+    for( i = 1; i < ctx->nr; i++ )
     {
         RK -= 8;
 
